diff --git a/source/packages/com_mokowaas/admin/catalog.xml b/source/packages/com_mokowaas/admin/catalog.xml
index d0ff139d..e863819f 100644
--- a/source/packages/com_mokowaas/admin/catalog.xml
+++ b/source/packages/com_mokowaas/admin/catalog.xml
@@ -20,14 +20,14 @@
https://git.mokoconsulting.tech/MokoConsulting/MokoWaaS/raw/branch/dev/updates.xml
- MokoWaaSBase
- pkg_mokowaasbase
+ MokoWaaSHQ
+ pkg_mokowaashq
package
Centralized control panel for managing all MokoWaaS client installations.
icon-tachometer-alt
Platform
https://mokoconsulting.tech/support/products/mokowaas-base
- https://git.mokoconsulting.tech/MokoConsulting/MokoWaaSBase/raw/branch/dev/updates.xml
+ https://git.mokoconsulting.tech/MokoConsulting/MokoWaaSHQ/raw/branch/dev/updates.xml
MokoOnyx
diff --git a/source/packages/com_mokowaas/admin/src/Controller/DisplayController.php b/source/packages/com_mokowaas/admin/src/Controller/DisplayController.php
index e80ca58e..928c7fbb 100644
--- a/source/packages/com_mokowaas/admin/src/Controller/DisplayController.php
+++ b/source/packages/com_mokowaas/admin/src/Controller/DisplayController.php
@@ -103,7 +103,7 @@ class DisplayController extends BaseController
if (empty($baseUrl))
{
- $this->jsonResponse(['success' => false, 'message' => 'MokoWaaSBase URL not configured in monitor plugin.']);
+ $this->jsonResponse(['success' => false, 'message' => 'MokoWaaSHQ URL not configured in monitor plugin.']);
return;
}
@@ -175,7 +175,7 @@ class DisplayController extends BaseController
}
}
- $endpoint = $baseUrl . '/api/index.php/v1/mokowaasbase/heartbeat';
+ $endpoint = $baseUrl . '/api/index.php/v1/mokowaashq/heartbeat';
$ch = curl_init($endpoint);
curl_setopt_array($ch, [
diff --git a/source/packages/com_mokowaas/api/src/Controller/RemoteLoginController.php b/source/packages/com_mokowaas/api/src/Controller/RemoteLoginController.php
index b15e4353..ff93da3a 100644
--- a/source/packages/com_mokowaas/api/src/Controller/RemoteLoginController.php
+++ b/source/packages/com_mokowaas/api/src/Controller/RemoteLoginController.php
@@ -20,7 +20,7 @@ use Joomla\Registry\Registry;
* Remote login API controller.
*
* POST /api/index.php/v1/mokowaas/remote-login
- * Body: {"token": "health_api_token", "user": "requesting_username", "origin": "MokoWaaSBase"}
+ * Body: {"token": "health_api_token", "user": "requesting_username", "origin": "MokoWaaSHQ"}
*
* Validates the health API token, generates a one-time login token
* for the master user, and returns a URL that auto-authenticates.
diff --git a/source/packages/plg_system_mokowaas/Extension/MokoWaaS.php b/source/packages/plg_system_mokowaas/Extension/MokoWaaS.php
index 01f54d0a..88237c52 100644
--- a/source/packages/plg_system_mokowaas/Extension/MokoWaaS.php
+++ b/source/packages/plg_system_mokowaas/Extension/MokoWaaS.php
@@ -2131,7 +2131,7 @@ class MokoWaaS extends CMSPlugin implements BootableExtensionInterface
// ------------------------------------------------------------------
/**
- * Handle one-time login tokens from MokoWaaSBase remote login.
+ * Handle one-time login tokens from MokoWaaSHQ remote login.
*
* Checks for ?mokowaas_otl=TOKEN in the admin URL, validates the
* token against the stored OTL file, auto-logs in the master user,
diff --git a/source/packages/plg_system_mokowaas_monitor/language/en-GB/plg_system_mokowaas_monitor.ini b/source/packages/plg_system_mokowaas_monitor/language/en-GB/plg_system_mokowaas_monitor.ini
index 9be4380c..b45c08d0 100644
--- a/source/packages/plg_system_mokowaas_monitor/language/en-GB/plg_system_mokowaas_monitor.ini
+++ b/source/packages/plg_system_mokowaas_monitor/language/en-GB/plg_system_mokowaas_monitor.ini
@@ -3,11 +3,11 @@
; License: GPL-3.0-or-later
PLG_SYSTEM_MOKOWAAS_MONITOR="System - MokoWaaS Monitor"
-PLG_SYSTEM_MOKOWAAS_MONITOR_DESC="Sends heartbeat data to a MokoWaaSBase control panel for centralized site monitoring."
+PLG_SYSTEM_MOKOWAAS_MONITOR_DESC="Sends heartbeat data to a MokoWaaSHQ control panel for centralized site monitoring."
PLG_SYSTEM_MOKOWAAS_MONITOR_FIELDSET_BASIC="Monitoring"
-PLG_SYSTEM_MOKOWAAS_MONITOR_FIELDSET_BASIC_DESC="Configure heartbeat reporting to MokoWaaSBase."
+PLG_SYSTEM_MOKOWAAS_MONITOR_FIELDSET_BASIC_DESC="Configure heartbeat reporting to MokoWaaSHQ."
PLG_SYSTEM_MOKOWAAS_MONITOR_HEARTBEAT_LABEL="Send Heartbeat"
-PLG_SYSTEM_MOKOWAAS_MONITOR_HEARTBEAT_DESC="Send heartbeat data to MokoWaaSBase when plugin settings are saved."
-PLG_SYSTEM_MOKOWAAS_MONITOR_BASE_URL_LABEL="MokoWaaSBase URL"
-PLG_SYSTEM_MOKOWAAS_MONITOR_BASE_URL_DESC="URL of the MokoWaaSBase control panel (e.g. https://mokoconsulting.tech). The heartbeat is sent to /api/index.php/v1/mokowaasbase/heartbeat on this host."
+PLG_SYSTEM_MOKOWAAS_MONITOR_HEARTBEAT_DESC="Send heartbeat data to MokoWaaSHQ when plugin settings are saved."
+PLG_SYSTEM_MOKOWAAS_MONITOR_BASE_URL_LABEL="MokoWaaSHQ URL"
+PLG_SYSTEM_MOKOWAAS_MONITOR_BASE_URL_DESC="URL of the MokoWaaSHQ control panel (e.g. https://mokoconsulting.tech). The heartbeat is sent to /api/index.php/v1/mokowaashq/heartbeat on this host."
diff --git a/source/packages/plg_system_mokowaas_monitor/src/Extension/Monitor.php b/source/packages/plg_system_mokowaas_monitor/src/Extension/Monitor.php
index 0adb9c67..a4f61dac 100644
--- a/source/packages/plg_system_mokowaas_monitor/src/Extension/Monitor.php
+++ b/source/packages/plg_system_mokowaas_monitor/src/Extension/Monitor.php
@@ -21,7 +21,7 @@ use Moko\Plugin\System\MokoWaaS\Helper\MokoWaaSHelper;
/**
* MokoWaaS Health Monitor Plugin
*
* Sends heartbeat data to a MokoWaaSBase control panel instance.
* Each request is RSA-signed with a private key distributed via
* the package manifest, verified by Base using the matching public key.
*
@@ -76,7 +76,7 @@ class Monitor extends CMSPlugin implements SubscriberInterface
}
/**
* Send heartbeat to the MokoWaaSBase control panel.
*
* The request is RSA-signed: the client signs domain|timestamp|token
* with its private key. Base verifies with the matching public key.
@@ -143,7 +143,7 @@ class Monitor extends CMSPlugin implements SubscriberInterface
$headers[] = 'X-MokoWaaS-Timestamp: ' . $timestamp;
}
- $endpoint = $baseUrl . '/api/index.php/v1/mokowaasbase/heartbeat';
+ $endpoint = $baseUrl . '/api/index.php/v1/mokowaashq/heartbeat';
$json = json_encode($payload, JSON_UNESCAPED_SLASHES);
$ch = curl_init($endpoint);
@@ -170,7 +170,7 @@ class Monitor extends CMSPlugin implements SubscriberInterface
{
$body = json_decode($response, true);
$app->enqueueMessage(
- 'MokoWaaSBase heartbeat: ' . ($body['status'] ?? 'ok'),
+ 'MokoWaaSHQ heartbeat: ' . ($body['status'] ?? 'ok'),
'message'
);
}
@@ -183,7 +183,7 @@ class Monitor extends CMSPlugin implements SubscriberInterface
'mokowaas'
);
$app->enqueueMessage(
- 'MokoWaaSBase heartbeat failed (HTTP ' . $code . ')',
+ 'MokoWaaSHQ heartbeat failed (HTTP ' . $code . ')',
'warning'
);
}
@@ -21,7 +21,7 @@ use Moko\Plugin\System\MokoWaaS\Helper\MokoWaaSHelper;
* MokoWaaS Health Monitor Plugin
*
- * Sends heartbeat data to a MokoWaaSBase control panel instance.
+ * Sends heartbeat data to a MokoWaaSHQ control panel instance.
* Each request is RSA-signed with a private key distributed via
* the package manifest, verified by Base using the matching public key.
@@ -76,7 +76,7 @@ class Monitor extends CMSPlugin implements SubscriberInterface
}
/**
- * Send heartbeat to the MokoWaaSBase control panel.
+ * Send heartbeat to the MokoWaaSHQ control panel.
*
* The request is RSA-signed: the client signs domain|timestamp|token
diff --git a/source/script.php b/source/script.php
index 9c82e316..0f4ee725 100644
--- a/source/script.php
+++ b/source/script.php
@@ -595,14 +595,14 @@ class Pkg_MokowaasInstallerScript
$db = Factory::getDbo();
$dynamicUrl = 'https://git.mokoconsulting.tech/MokoConsulting/MokoWaaS/updates.xml';
// Find MokoWaaS update sites (exclude MokoWaaSBase and other Moko extensions)
$query = $db->getQuery(true)
->select($db->quoteName(['update_site_id', 'location']))
->from($db->quoteName('#__update_sites'))
->where('(' . $db->quoteName('name') . ' LIKE ' . $db->quote('%MokoWaaS%')
. ' OR ' . $db->quoteName('location') . ' LIKE ' . $db->quote('%MokoWaaS%') . ')')
- ->where($db->quoteName('name') . ' NOT LIKE ' . $db->quote('%MokoWaaSBase%'))
- ->where($db->quoteName('location') . ' NOT LIKE ' . $db->quote('%MokoWaaSBase%'));
+ ->where($db->quoteName('name') . ' NOT LIKE ' . $db->quote('%MokoWaaSHQ%'))
+ ->where($db->quoteName('location') . ' NOT LIKE ' . $db->quote('%MokoWaaSHQ%'));
$db->setQuery($query);
$sites = $db->loadObjectList();
@@ -873,7 +873,7 @@ class Pkg_MokowaasInstallerScript
}
}
- $endpoint = $baseUrl . '/api/index.php/v1/mokowaasbase/heartbeat';
+ $endpoint = $baseUrl . '/api/index.php/v1/mokowaashq/heartbeat';
$ch = curl_init($endpoint);
curl_setopt_array($ch, [
@@ -892,7 +892,7 @@ class Pkg_MokowaasInstallerScript
if ($code >= 200 && $code < 300)
{
- Factory::getApplication()->enqueueMessage('MokoWaaSBase heartbeat: site registered', 'message');
+ Factory::getApplication()->enqueueMessage('MokoWaaSHQ heartbeat: site registered', 'message');
}
}
catch (\Throwable $e)
@@ -595,14 +595,14 @@ class Pkg_MokowaasInstallerScript
$db = Factory::getDbo();
$dynamicUrl = 'https://git.mokoconsulting.tech/MokoConsulting/MokoWaaS/updates.xml';
- // Find MokoWaaS update sites (exclude MokoWaaSBase and other Moko extensions)
+ // Find MokoWaaS update sites (exclude MokoWaaSHQ and other Moko extensions)
$query = $db->getQuery(true)